.. _blast2gff:

blast2gff - Convert BLAST output to GFF
=======================================

Overview
--------

.. automodule:: mgkit.workflow.blast2gff

Options
-------

.. click:: mgkit.workflow.blast2gff:main
   :prog: blast2gff
   :show-nested:
